time_conversion: Time Conversion

Description Usage Arguments Value Examples

View source: R/time_conversion.R

Description

Function to take in years and months desired and output a list in the form of YYYYMM

Usage

1

Arguments

years

A list containing desired years entered as text elements ie the string "2012"

months

A list containing desired months as text elements of the form MM (01-12) ie the string "01" represents January and so on.

Value

a list of dates formated YYYYMM

Examples

1
2
  #Outputs a list of all first quarter months 2010 - 2020 formatted YYYYMM
  time_conversion(years = list("2010","2011", "2012", "2013", "2014", "2015", "2016", "2017", "2018", "2019", "2020") months = list("01", "02", "03"))

jlesniak12/UNcommtradeAPI documentation built on Jan. 10, 2021, 12:07 a.m.