Description Usage Arguments Value Examples
View source: R/time_conversion.R
Function to take in years and months desired and output a list in the form of YYYYMM
1 | time_conversion(years, months)
|
years |
A list containing desired years entered as text elements ie the string "2012" |
months |
A list containing desired months as text elements of the form MM (01-12) ie the string "01" represents January and so on. |
a list of dates formated YYYYMM
1 2 | #Outputs a list of all first quarter months 2010 - 2020 formatted YYYYMM
time_conversion(years = list("2010","2011", "2012", "2013", "2014", "2015", "2016", "2017", "2018", "2019", "2020") months = list("01", "02", "03"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.